summaryrefslogtreecommitdiff
path: root/pango/pango-ot-ruleset.c
diff options
context:
space:
mode:
authorBehdad Esfahbod <behdad@gnome.org>2007-10-25 23:37:11 +0000
committerBehdad Esfahbod <behdad@src.gnome.org>2007-10-25 23:37:11 +0000
commit481f02efdb53542ce6fb1f5821cb6a4cfc83abee (patch)
tree0b88eadb7adbdcbb00c365f926d11c47e7a97c51 /pango/pango-ot-ruleset.c
parent18247866c5843087f0e32c871449400f0d74b7f4 (diff)
downloadpango-481f02efdb53542ce6fb1f5821cb6a4cfc83abee.tar.gz
Even more cleanup and more type renames.
2007-10-25 Behdad Esfahbod <behdad@gnome.org> * pango/opentype/*: Even more cleanup and more type renames. svn path=/trunk/; revision=2478
Diffstat (limited to 'pango/pango-ot-ruleset.c')
-rw-r--r--pango/pango-ot-ruleset.c12
1 files changed, 6 insertions, 6 deletions
diff --git a/pango/pango-ot-ruleset.c b/pango/pango-ot-ruleset.c
index ddd92c3f..f2686e39 100644
--- a/pango/pango-ot-ruleset.c
+++ b/pango/pango-ot-ruleset.c
@@ -29,7 +29,7 @@ typedef struct _PangoOTRule PangoOTRule;
struct _PangoOTRule
{
gulong property_bit;
- FT_UShort feature_index;
+ HB_UShort feature_index;
guint table_type : 1;
};
@@ -414,7 +414,7 @@ pango_ot_ruleset_maybe_add_feature (PangoOTRuleset *ruleset,
*
* This is a convenience function that
* for each feature in the feature map array @features
* converts the feature name to a #PangoOTTag feature tag using FT_MAKE_TAG()
* and calls pango_ot_ruleset_maybe_add_feature() on it.
*
* Return value: The number of features in @features that were found
@@ -435,10 +435,10 @@ pango_ot_ruleset_maybe_add_features (PangoOTRuleset *ruleset,
for (i = 0; i < n_features; i++)
{
- PangoOTTag feature_tag = FT_MAKE_TAG (features[i].feature_name[0],
- features[i].feature_name[1],
- features[i].feature_name[2],
- features[i].feature_name[3]);
+ PangoOTTag feature_tag = PANGO_OT_TAG_MAKE (features[i].feature_name[0],
+ features[i].feature_name[1],
+ features[i].feature_name[2],
+ features[i].feature_name[3]);
n_found_features += pango_ot_ruleset_maybe_add_feature (ruleset,
table_type,
@@ -414,7 +414,7 @@ pango_ot_ruleset_maybe_add_feature (PangoOTRuleset *ruleset,
* This is a convenience function that
* for each feature in the feature map array @features
- * converts the feature name to a #PangoOTTag feature tag using FT_MAKE_TAG()
+ * converts the feature name to a #PangoOTTag feature tag using PANGO_OT_TAG_MAKE()
* and calls pango_ot_ruleset_maybe_add_feature() on it.
*